<?php

class listing_posts extends WP_Widget
{

	function __construct() {
        parent::__construct(
				'listing_posts', // Base ID
				'&#x1F537; ' . esc_html__( 'Listings Recently Posts', 'gt3_wize_core'), // Name
				array(
						'description' => esc_html__( 'Listings Recently Posts', 'gt3_wize_core' ),
				) // Widget Options
		);
    }

    function widget($args, $instance)
    {
        $after_widget = $before_widget = $before_title = $after_title = '';

        extract($args);

		if (get_post_type() === 'job_listing') {

			echo  $before_widget;

			$postsArgs = array(
				'showposts' => $instance['posts_widget_number'],
				'offset' => 0,
				'orderby' => 'date',
				'order' => 'DESC',
				'post_type' => 'job_listing',
				'post_status' => 'publish',
				'ignore_sticky_posts' => 1
			);

			$compilepopular = '';

			$gt3_wp_query_posts = new WP_Query();
			$gt3_wp_query_posts->query($postsArgs);
			while ($gt3_wp_query_posts->have_posts()) : $gt3_wp_query_posts->the_post();
				$gt3_theme_featured_image_latest = wp_get_attachment_image_src(get_post_thumbnail_id(get_the_ID()), 'single-post-thumbnail');
				$post_meta = get_post_meta(get_the_ID());
				$post_location = !empty($post_meta['_job_location']) ? $post_meta['_job_location'][0] : '';
				$post_discount = !empty($post_meta['_discount']) ? $post_meta['_discount'][0] : '';

				$compilepopular .= '
				<li ' . ((!empty($gt3_theme_featured_image_latest)) ? 'class="with_img"' : '') . '>';
				if (empty($gt3_theme_featured_image_latest)) {
					$widg_img = '';
				} else {
					$widg_img = '<a href="' . esc_url(get_permalink()) . '" class="listing_recent_posts_image"><img src="' . esc_url(aq_resize($gt3_theme_featured_image_latest[0], "620", "420", true, true, true)) . '" alt="' . get_the_title() . '">';
					if (isset($post_discount) && $post_discount !== '' && $post_discount !== '0%') {
						$widg_img .= '<div class="discount_label">'. esc_html__('Discount', 'gt3_wize_core') . ' ' . esc_attr($post_discount) .'</div>';
					}
					$widg_img .= '</a>';
				}

				$compilepopular .= '
					<div class="recent_posts_content">
						' . $widg_img . '
						<h4 class="post_title"><a href="' . esc_url(get_permalink()) . '">' . get_the_title() . '</a></h4>';
						if (strlen($post_location) > 0) {
							$compilepopular .= '
							<div class="listing_meta">
								<span><i class="fa fa-map-marker"></i>' . esc_attr($post_location) . '</span>
							</div>';
						}
						$compilepopular .= '
					</div>
				</li>';

			endwhile;
			wp_reset_postdata();

			echo '
				<div class="listing_widget_wrapper">
			';
			if ($instance['widget_title'] !== '') {
				echo  $before_title;
				echo esc_attr($instance['widget_title']);
				echo  $after_title;
			}
			if ($instance['widget_subtitle'] !== '') {
				echo '<div class="widget-subtitle">' . $instance['widget_subtitle'] . '</div>';
			}
			echo '
					<ul class="recent_posts">
						' . $compilepopular . '
					</ul>
				</div>
			';

			#END OUTPUT
			echo  $after_widget;
		}
    }


    function update($new_instance, $old_instance)
    {
        $instance = $old_instance;

        $instance['widget_title'] = esc_attr($new_instance['widget_title']);
		$instance['widget_subtitle'] = esc_attr($new_instance['widget_subtitle']);
        $instance['posts_widget_number'] = absint($new_instance['posts_widget_number']);

	    do_action( 'wpml_register_single_string', 'Widgets', 'Listings Recently Posts - Title', $instance['widget_title'] );
	    do_action( 'wpml_register_single_string', 'Widgets', 'Listings Recently Posts - SubTitle', $instance['widget_subtitle'] );

        return $instance;
    }

    function form($instance)
    {
        $defaultValues = array(
            'widget_title' => esc_html__( 'Recently Added', 'gt3_wize_core' ),
			'widget_subtitle' => '',
            'posts_widget_number' => '3'
        );
        $instance = wp_parse_args((array)$instance, $defaultValues);
        ?>
        <table class="fullwidth">
            <tr>
                <td><?php echo esc_html__( 'Title:', 'gt3_wize_core' ); ?></td>
                <td><input type='text' class="fullwidth" name='<?php echo esc_attr($this->get_field_name('widget_title')); ?>'
                           value='<?php echo esc_attr($instance['widget_title']); ?>'/></td>
            </tr>
            <tr>
                <td><?php echo esc_html__( 'Subtitle:', 'gt3_wize_core' ); ?></td>
                <td><input type='text' class="fullwidth" name='<?php echo esc_attr($this->get_field_name('widget_subtitle')); ?>'
                           value='<?php echo esc_attr($instance['widget_subtitle']); ?>'/></td>
            </tr>
            <tr>
                <td><?php echo esc_html__( 'Number:', 'gt3_wize_core' ); ?></td>
                <td><input type='text' class="fullwidth"
                           name='<?php echo esc_attr($this->get_field_name('posts_widget_number')); ?>'
                           value='<?php echo esc_attr($instance['posts_widget_number']); ?>'/></td>
            </tr>
        </table>
    <?php
    }
}

function listing_posts_register_widgets()
{
    register_widget('listing_posts');
}

add_action('widgets_init', 'listing_posts_register_widgets');

?>
